@@ -162,7 +162,6 @@ predict_runtime <- function(
 #'   of the names of the targets assigned to each worker.
 #'   For each worker, targets are listed in the order they are assigned.
 #' @param config option internal runtime parameter list of
-#'   \code{\link{make}(...)},
 #'   produced by both [make()] and
 #'   [drake_config()].
 #' @param targets Character vector, names of targets.
@@ -204,6 +203,7 @@ predict_load_balancing <- function(
   default_time = 0,
   warn = TRUE
 ){
+  assert_pkgs("lubridate")
   if (!is.null(future_jobs) || !is.null(digits)){
     warning(
       "The `future_jobs` and `digits` arguments ",
