@@ -27,7 +27,7 @@ test_with_dir("responses to imported file", {
   # actually change file
   saveRDS(2:10, "input.rds")
   testrun(config)
-  expect_equal(justbuilt(config), sort(c("\"intermediatefile.rds\"",
-    "combined", "final", "myinput", "nextone")))
+  expect_equal(justbuilt(config), sort(c(
+    "drake_target_1", "combined", "final", "myinput", "nextone")))
   expect_false(length(final0) == length(readd(final, search = FALSE)))
 })
